# -*- coding: utf-8 -*-
""""
________________________________________________________________________________
FLASIK: https://github.com/mardix/flasik
________________________________________________________________________________

That's the application's entry point
"""

from flasik import Init


# == Commander ==
# Import commander to use your own command line functions.
# Comment out to omit
import application.commander

# == Views ==
# a dict with list of views to load by name
# ie: `flasik=main flasik-admin run` will serve all the views in the `main` list
# Views are placed in application/views directory, and should be listed as string
# without the `.py`
# You can add as many views as you want, containing as many views
# It also allows you to use multiple config env
# ie: `flasik=main:production flasik-admin run` will use the `main` project with
# `production` config


views = {
    "main": [
        "main"
    ]
}

# == INIT ==
# Init the application
# 'app' variable is required to use the commander -> flasik
app = Init(__name__, views)



# -*- coding: utf-8 -*-
# Mocha

import os

# ------------------------------------------------------------------------------
# A convenient utility to access data path from your application and config files

# The application directory
# /apps
APP_DIR = os.path.dirname(__file__)

# The root dir
# /
ROOT_DIR = os.path.dirname(APP_DIR)

# Data directory
# apps/var
VAR_DIR = os.path.join(APP_DIR, "var")


def get_var_path(path):
    """
    get the path stored in the 'app/data' directory
    :param path: string
    :return: string
    """
    return os.path.join(VAR_DIR, path)





@flasik.extends
def _setup_logger(cls):
    logging_config = app.config.get("LOGGING")
    if not logging_config:
        logging_config = {
            "version": 1,
            "handlers": {
                "default": {
                    "class": app.config.get("LOGGING_CLASS", "logging.StreamHandler")
                }
            },
            'loggers': {
                '': {
                    'handlers': ['default'],
                    'level': 'WARN',
                }
            }
        }

    logging.config.dictConfig(logging_config)
    logger = logging.getLogger("root")
    app._logger = logger
